function findNearestLinks (linkset,feature,addbuf,within)
//
// this functions uses the turfjs libray functions to locate links falling within a certain buffered distance
// (in miles) of an input feature. For point buffer, returns sort order distance from line
//
{
//
// create buffer circle
//
   var outset=new Array();
   var buffer=turf.buffer(feature,addbuf,{units: 'miles',steps: 64});
   var box=turf.bbox(buffer);
//   var bufout=JSON.stringify(buffer);
//
// build qualifying links array to index loop
//
   var qlinks=inBounds(linkset,box);
   var j=0;
   for (var i=0;i<qlinks.length;i++)
   {
      var matchct=0;
      var link=turf.lineString(linkset[qlinks[i]].geometry.coordinates);
      if (!within)
      {
         var matches=turf.lineIntersect(buffer,link);
         matchct=matches.features.length;
      }
//
// if link or part of link in the polygon add to match array - last "0" is placeholder for "exposure" sort
//
      var d=null;
      if (matchct>0 || turf.booleanContains(buffer,link) && feature.properties.INDEX!=link) 
      {
         if (turf.getType(feature)=="Point") var d=turf.pointToLineDistance(feature,link,{units: 'miles'});
         outset[j]=[qlinks[i],d,0];
         j++;
      }
   }
   return outset.sort(function(a,b) {return a[1]-b[1]});
}
function findNearestNodes (linkset,feature,addbuf,within)
//
// this functions uses the turfjs library functions to locate links falling within a certain buffered distance
// (in miles) of an input feature. The routine returns the index of the node within the buffer and the 
// associated link index.
//
{
//
// create buffer circle
//
   var outset=new Array();
   var buffer=turf.buffer(feature,addbuf,{units: 'miles',steps: 64});
   var coord=turf.getCoord(feature);
   var box=turf.bbox(buffer);
//   var bufout=JSON.stringify(buffer);
//
// build qualifying links array to index loop
//
   var qnodes=new Array();
   var qlinks=inBounds(linkset,box);
   var j=0;
   for (var i=0;i<qlinks.length;i++)
   {
      if (turf.booleanContains(buffer,turf.point(linkset[qlinks[i]].APOS))) 
         qnodes.push([qlinks[i],linkset[qlinks[i]].properties.ANODE,turf.distance(coord,linkset[qlinks[i]].APOS,{units: 'miles'})]);
      if (turf.booleanContains(buffer,turf.point(linkset[qlinks[i]].BPOS))) 
         qnodes.push([qlinks[i],linkset[qlinks[i]].properties.BNODE,turf.distance(coord,linkset[qlinks[i]].BPOS,{units: 'miles'})]);
   }
//
// sort qnodes on distance
//
   qnodes=qnodes.sort(function(a,b) {return a[2]-b[2]});
   return qnodes;
}

function inBounds(links,bounds)
//
// this function is a wrapper for finding links based on position and through spatial indexing
// the spatial indexing model will be added to the front end. Currently, the model appllies a 
// simple bounding box to find qualifying links
//
//
// look up index range based on latitude
//
//
// determine if low/high extent are outside bounding box
//
{
   qlinks=new Array();
   for (var i=1;i<links.length;i++)
   {
      var inbounds=true;
           if (links[i].HEXT[0]<bounds[0]) inbounds=false; //left of buffer
      else if (links[i].HEXT[1]<bounds[1]) inbounds=false; //below buffer
      else if (links[i].LEXT[0]>bounds[2]) inbounds=false; //right of buffer
      else if (links[i].LEXT[1]>bounds[3]) inbounds=false; //above buffer
//
// if in is true, push link index onto return stack
//
      if (inbounds) qlinks.push(i);
   }
   return qlinks;
}
function checkEndNodes(snet,slink,tnet,tlink,addbuf,reverse)
//
// this function performs a fuzzy tolerance check of two A and B nodes for two links
// it's primary purpose is to see if a link identified a reserve of slink meets the criteria
// the reverse flag indicate that A=B and B=A are being tested
// it returns true or false depending on whether the nodes compared can be considered tolerant
//   
{
   var result=false;
   if (reverse==null)
   {
       var d1=turf.distance(snet[slink].APOS,tnet[tlink].APOS,{units: 'miles'})
       var d2=turf.distance(snet[slink].BPOS,tnet[tlink].BPOS,{units: 'miles'})
   }
   else
   {
       var d1=turf.distance(snet[slink].APOS,tnet[tlink].BPOS,{units: 'miles'})
       var d2=turf.distance(snet[slink].BPOS,tnet[tlink].APOS,{units: 'miles'})
   }
   if (d1<=addbuf && d2<=addbuf) result=true;
   return result; 	
} 